@@ -1,4 +1,4 @@
-from robot.api.parsing import Comment, EmptyLine, End, ModelTransformer, Token
+from robot.api.parsing import Comment, EmptyLine, End, Token
 
 try:
     from robot.api.parsing import InlineIfHeader
@@ -6,9 +6,10 @@ except ImportError:
     InlineIfHeader = None
 
 from robotidy.disablers import skip_if_disabled, skip_section_if_disabled
+from robotidy.transformers import Transformer
 
 
-class AddMissingEnd(ModelTransformer):
+class AddMissingEnd(Transformer):
     """
     Add missing END token to FOR loops and IF statements.
 
@@ -30,10 +31,11 @@ class AddMissingEnd(ModelTransformer):
             Log    ${x}
         END
     ```
-
-    Supports global formatting params: ``--startline`` and ``--endline``.
     """
 
+    def __init__(self):
+        super().__init__()  # workaround for our dynamically imported classes with args from cli/config
+
     def fix_block(self, node, expected_type):
         self.generic_visit(node)
         self.fix_header_name(node, expected_type)
