@@ -1,6 +1,10 @@
-from robot.api.parsing import ModelTransformer, Token
+from robot.api.parsing import Token
 
 from robotidy.disablers import skip_if_disabled
+from robotidy.exceptions import InvalidParameterValueError
+from robotidy.skip import Skip
+from robotidy.transformers import Transformer
+from robotidy.transformers.run_keywords import get_run_keywords
 from robotidy.utils import (
     collect_comments_from_tokens,
     get_new_line,
@@ -13,16 +17,7 @@ from robotidy.utils import (
 )
 
 
-class RunKeywordVariant:
-    def __init__(self, libname, name, resolve=1, branches=None, split_on_and=False):
-        self.libname = normalize_name(libname)
-        self.name = normalize_name(name)
-        self.resolve = resolve
-        self.branches = branches
-        self.split_on_and = split_on_and
-
-
-class IndentNestedKeywords(ModelTransformer):
+class IndentNestedKeywords(Transformer):
     """
     Format indentation inside run keywords variants such as ``Run Keywords`` or
     ``Run Keyword And Continue On Failure``.
@@ -47,74 +42,56 @@ class IndentNestedKeywords(ModelTransformer):
         ...        Log    baz
     ```
 
-    It is possible to provide extra indentation for keywords using ``AND`` separators
-    by configuring ``indent_and`` to ``True``:
-    ```
-    robotidy -c IndentNestedKeywords:indent_and=True src
-    ```
-
-    It will result in:
-    ```
-    Run keywords
-    ...        Log    foo
-    ...    AND
-    ...        Log    bar
-    ```
+    ``AND`` argument inside ``Run Keywords`` can be handled in different ways. It is controlled via ``indent_and``
+    parameter. For more details see the full documentation.
 
     To skip formatting run keywords inside settings (such as ``Suite Setup``, ``[Setup]``, ``[Teardown]`` etc.) set
     ``skip_settings`` to ``True``.
     """
 
     ENABLED = False
-    RUN_KW = [
-        RunKeywordVariant("BuiltIn", "Run Keyword"),
-        RunKeywordVariant("BuiltIn", "Run Keyword And Continue On Failure"),
-        RunKeywordVariant("BuiltIn", "Run Keyword And Expect Error", resolve=2),
-        RunKeywordVariant("BuiltIn", "Run Keyword And Ignore Error"),
-        RunKeywordVariant("BuiltIn", "Run Keyword And Return"),
-        RunKeywordVariant("BuiltIn", "Run Keyword And Return If", resolve=2),
-        RunKeywordVariant("BuiltIn", "Run Keyword And Return Status"),
-        RunKeywordVariant("BuiltIn", "Run Keyword And Warn On Failure"),
-        RunKeywordVariant("BuiltIn", "Run Keyword If", resolve=2, branches=["ELSE IF", "ELSE"]),
-        RunKeywordVariant("BuiltIn", "Run Keyword If All Tests Passed"),
-        RunKeywordVariant("BuiltIn", "Run Keyword If Any Tests Failed"),
-        RunKeywordVariant("BuiltIn", "Run Keyword If Test Failed"),
-        RunKeywordVariant("BuiltIn", "Run Keyword If Test Passed"),
-        RunKeywordVariant("BuiltIn", "Run Keyword If Timeout Occurred"),
-        RunKeywordVariant("BuiltIn", "Run Keyword Unless", resolve=2),
-        RunKeywordVariant("BuiltIn", "Run Keywords", split_on_and=True),
-        RunKeywordVariant("BuiltIn", "Repeat Keyword", resolve=2),
-        RunKeywordVariant("BuiltIn", "Wait Until Keyword Succeeds", resolve=3),
-    ]
+    HANDLES_SKIP = frozenset({"skip_settings"})
 
-    def __init__(self, indent_and: bool = False, skip_settings: bool = False):
+    def __init__(self, indent_and: str = "split", skip: Skip = None):
+        super().__init__(skip=skip)
         self.indent_and = indent_and
-        self.skip_settings = skip_settings
-        self.run_keywords = dict()
-        for run_kw in self.RUN_KW:
-            self.run_keywords[run_kw.name] = run_kw
-            self.run_keywords[f"{run_kw.libname}.{run_kw.name}"] = run_kw
+        self.validate_indent_and()
+        self.run_keywords = get_run_keywords()
+
+    def validate_indent_and(self):
+        modes = {"keep_in_line", "split", "split_and_indent"}
+        if self.indent_and not in modes:
+            raise InvalidParameterValueError(
+                self.__class__.__name__,
+                "indent_and",
+                self.indent_and,
+                f"Select one of: {','.join(modes)}",
+            )
 
     def get_run_keyword(self, kw_name):
         kw_norm = normalize_name(kw_name)
         return self.run_keywords.get(kw_norm, None)
 
     def get_setting_lines(self, node):  # noqa
-        if self.skip_settings or node.errors or not len(node.data_tokens) > 1:
+        if self.skip.setting("any") or node.errors or not len(node.data_tokens) > 1:
             return None
         run_keyword = self.get_run_keyword(node.data_tokens[1].value)
         if not run_keyword:
             return None
         return self.parse_sub_kw(node.data_tokens[1:])
 
-    def get_separator(self, column=1):
-        return Token(Token.SEPARATOR, self.formatting_config.separator * column)
+    def get_separator(self, column=1, continuation=False):
+        if continuation:
+            separator = self.formatting_config.continuation_indent * column
+        else:
+            separator = self.formatting_config.separator * column
+        return Token(Token.SEPARATOR, separator)
 
     def parse_keyword_lines(self, lines, tokens, new_line, eol):
         separator = self.get_separator()
         for column, line in lines[1:]:
             tokens.extend(new_line)
-            tokens.append(self.get_separator(column))
+            tokens.append(self.get_separator(column, True))
             tokens.extend(join_tokens_with_token(line, separator))
         tokens.append(eol)
         return tokens
@@ -209,9 +186,14 @@ class IndentNestedKeywords(ModelTransformer):
         if is_token_value_in_tokens("AND", tokens):
             while is_token_value_in_tokens("AND", tokens):
                 prefix, branch, tokens = split_on_token_value(tokens, "AND", 1)
-                lines.extend(self.parse_sub_kw(prefix, column + 1 + int(self.indent_and)))
-                lines.append((column + 1, branch))
-            lines.extend(self.parse_sub_kw(tokens, column + 1 + int(self.indent_and)))
+                if self.indent_and == "keep_in_line":
+                    lines.extend(self.parse_sub_kw(prefix + branch, column + 1))
+                else:
+                    indent = int(self.indent_and == "split_and_indent")  # indent = 1 for split_and_indent, else 0
+                    lines.extend(self.parse_sub_kw(prefix, column + 1 + indent))
+                    lines.append((column + 1, branch))
+            indent = int(self.indent_and == "split_and_indent")  # indent = 1 for split_and_indent, else 0
+            lines.extend(self.parse_sub_kw(tokens, column + 1 + indent))
         else:
             lines.extend([(column + 1, [kw_token]) for kw_token in tokens])
         return lines
