@@ -9,6 +9,7 @@ If you don't want to run your transformer by default and only when calling robot
 then add ``ENABLED = False`` class attribute inside.
 """
 import copy
+import textwrap
 from itertools import chain
 from typing import Dict, Optional
 
@@ -21,9 +22,9 @@ from robot.api.parsing import ModelTransformer
 from robot.errors import DataError
 from robot.utils.importer import Importer
 
-from robotidy.disablers import Skip, SkipConfig
 from robotidy.exceptions import ImportTransformerError, InvalidParameterError, InvalidParameterFormatError
-from robotidy.utils import ROBOT_VERSION, RecommendationFinder
+from robotidy.skip import Skip, SkipConfig
+from robotidy.utils import ROBOT_VERSION, RecommendationFinder, split_args_from_name_or_path
 
 TRANSFORMERS = [
     "AddMissingEnd",
@@ -53,15 +54,65 @@ TRANSFORMERS = [
     "ReplaceReturns",
     "ReplaceBreakContinue",
     "InlineIf",
+    "Translate",
 ]
 
 
 IMPORTER = Importer()
 
 
+class TransformType(click.ParamType):
+    name = "transform"
+
+    def convert(self, value, param, ctx):
+        name, args = split_args_from_name_or_path(value.replace(" ", ""))
+        return name, args
+
+
+class TransformerParameter:
+    def __init__(self, name, default_value):
+        self.name = name
+        self.value = default_value
+
+    def __str__(self):
+        if self.value is not None and str(self.value) != "":
+            return f"{self.name} : {self.value}"
+        return self.name
+
+
+class TransformerContainer:
+    """
+    Stub for transformer container class that holds the transformer instance and its metadata.
+    """
+
+    def __init__(self, instance, argument_names, spec):
+        self.instance = instance
+        self.name = instance.__class__.__name__
+        self.enabled_by_default = getattr(instance, "ENABLED", True)
+        self.parameters = self.get_parameters(argument_names, spec)
+
+    def get_parameters(self, argument_names, spec):
+        params = []
+        for arg in argument_names:
+            if arg == "enabled":
+                default = self.enabled_by_default
+            else:
+                default = spec.defaults.get(arg, None)
+            params.append(TransformerParameter(arg, default))
+        return params
+
+    def __str__(self):
+        s = f"## Transformer {self.name}\n" + textwrap.dedent(self.instance.__doc__)
+        if self.parameters:
+            s += "\nSupported parameters:\n  - " + "\n - ".join(str(param) for param in self.parameters) + "\n"
+        s += f"\nSee <https://robotidy.readthedocs.io/en/latest/transformers/{self.name}.html> for more examples."
+        return s
+
+
 class Transformer(ModelTransformer):
     def __init__(self, skip: Optional[Skip] = None):
         self.formatting_config = None  # to make lint happy (we're injecting the configs)
+        self.languages = None
         self.transformers: Dict = dict()
         self.disablers = None
         self.skip = skip
@@ -73,7 +124,7 @@ def import_transformer(name, args, skip):
         imported_class = IMPORTER.import_class_or_module(name)
         spec = IMPORTER._get_arg_spec(imported_class)
         handles_skip = getattr(imported_class, "HANDLES_SKIP", {})
-        positional, named = resolve_args(short_name, spec, args, skip, handles_skip=handles_skip)
+        positional, named, argument_names = resolve_args(short_name, spec, args, skip, handles_skip=handles_skip)
     except DataError:
         similar_finder = RecommendationFinder()
         similar = similar_finder.find_similar(short_name, TRANSFORMERS)
@@ -81,7 +132,8 @@ def import_transformer(name, args, skip):
             f"Importing transformer '{short_name}' failed. "
             f"Verify if correct name or configuration was provided.{similar}"
         ) from None
-    return imported_class(*positional, **named)
+    instance = imported_class(*positional, **named)
+    return TransformerContainer(instance, argument_names, spec)
 
 
 def split_args_to_class_and_skip(args):
@@ -97,14 +149,9 @@ def split_args_to_class_and_skip(args):
     return filtered_args, skip_args
 
 
-def assert_class_accepts_arguments(transformer, args, spec):
-    if args and not spec.argument_names:
-        raise InvalidParameterError(transformer, " This transformer does not accept arguments but they were provided.")
-
-
 def resolve_argument_names(argument_names, handles_skip):
     """Get transformer argument names with resolved skip parameters."""
-    new_args = ["enable"]
+    new_args = ["enabled"]
     if "skip" not in argument_names:
         return new_args + argument_names
     new_args.extend([arg for arg in argument_names if arg != "skip"])
@@ -112,17 +159,16 @@ def resolve_argument_names(argument_names, handles_skip):
     return new_args
 
 
-def assert_handled_arguments(transformer, args, spec, handles_skip):
+def assert_handled_arguments(transformer, args, argument_names):
     """Check if provided arguments are handled by given transformer.
     Raises InvalidParameterError if arguments does not match."""
     arg_names = [arg.split("=")[0] for arg in args]
     for arg in arg_names:
         # it's fine to only check for first non-matching parameter
-        argument_names = resolve_argument_names(spec.argument_names, handles_skip)
         if arg not in argument_names:
             similar_finder = RecommendationFinder()
             similar = similar_finder.find_similar(arg, argument_names)
-            if not similar:
+            if not similar and argument_names:
                 arg_names = "\n    " + "\n    ".join(argument_names)
                 similar = f" This transformer accepts following arguments:{arg_names}"
             raise InvalidParameterError(transformer, similar) from None
@@ -163,14 +209,14 @@ def resolve_args(transformer, spec, args, global_skip, handles_skip):
     "skip" parameter the Skip class will be also added to class arguments.
     """
     args, skip_args = split_args_to_class_and_skip(args)
-    assert_class_accepts_arguments(transformer, args, spec)
-    assert_handled_arguments(transformer, args, spec, handles_skip)
+    argument_names = resolve_argument_names(spec.argument_names, handles_skip)
+    assert_handled_arguments(transformer, args, argument_names)
     try:
         positional, named = spec.resolve(args)
         named = dict(named)
         if "skip" in spec.argument_names:
             named["skip"] = get_skip_class(spec, skip_args, global_skip)
-        return positional, named
+        return positional, named, argument_names
     except ValueError as err:
         raise InvalidParameterError(transformer, f" {err}") from None
 
@@ -180,7 +226,7 @@ def resolve_core_import_path(name):
     return f"robotidy.transformers.{name}" if name in TRANSFORMERS else name
 
 
-def load_transformer(name, args, skip):
+def load_transformer(name, args, skip) -> Optional[TransformerContainer]:
     if not args.get("enabled", True):
         return None
     import_name = resolve_core_import_path(name)
@@ -240,31 +286,61 @@ def can_run_in_robot_version(transformer, overwritten, target_version):
     return False
 
 
-def load_transformers(allowed_transformers, config, target_version, skip=None, allow_disabled=False, force_order=False):
+def assert_not_duplicated_transform(allowed_mapped, allowed_transformers):
+    """
+    Warns if user provides duplicated transformer names in --transform option.
+    """
+    if not allowed_mapped or len(allowed_mapped) == len(allowed_transformers):
+        return
+    transformers, reported = set(), set()
+    for name, _ in allowed_transformers:
+        if name in transformers and name not in reported:
+            reported.add(name)
+            click.echo(
+                f"Duplicated transformer '{name}' in the transform option. "
+                f"It will be run only once with the configuration from the last transform."
+            )
+        else:
+            transformers.add(name)
+
+
+def load_transformers(
+    allowed_transformers,
+    config,
+    target_version,
+    skip=None,
+    allow_disabled=False,
+    force_order=False,
+    allow_version_mismatch=True,
+):
     """Dynamically load all classes from this file with attribute `name` defined in allowed_transformers"""
     loaded_transformers = []
     allowed_mapped = {name: args for name, args in allowed_transformers} if allowed_transformers else {}
+    assert_not_duplicated_transform(allowed_mapped, allowed_transformers)
     validate_config(config, allowed_mapped)
     if not force_order:
         for name in TRANSFORMERS:
             if not allowed_mapped or name in allowed_mapped:
                 args = get_args(name, allowed_mapped, config)
-                imported_class = load_transformer(name, args, skip)
-                if imported_class is None:
+                container = load_transformer(name, args, skip)
+                if container is None:
                     continue
-                enabled = getattr(imported_class, "ENABLED", True) or args.get("enabled", False)
+                enabled = getattr(container.instance, "ENABLED", True) or args.get("enabled", False)
                 if allowed_mapped or allow_disabled or enabled:
                     overwritten = name in allowed_mapped or args.get("enabled", False)
-                    if can_run_in_robot_version(imported_class, overwritten=overwritten, target_version=target_version):
-                        loaded_transformers.append(imported_class)
-                    elif allow_disabled:
-                        setattr(imported_class, "ENABLED", False)
-                        loaded_transformers.append(imported_class)
+                    if can_run_in_robot_version(
+                        container.instance, overwritten=overwritten, target_version=target_version
+                    ):
+                        loaded_transformers.append(container)
+                    elif allow_version_mismatch and allow_disabled:
+                        setattr(container.instance, "ENABLED", False)
+                        container.enabled_by_default = False
+                        loaded_transformers.append(container)
     for name in allowed_mapped:
         if force_order or name not in TRANSFORMERS:
             args = get_args(name, allowed_mapped, config)
-            imported_class = load_transformer(name, args, skip)
-            if imported_class is not None:
-                if can_run_in_robot_version(imported_class, overwritten=True, target_version=target_version):
-                    loaded_transformers.append(imported_class)
+            container = load_transformer(name, args, skip)
+            if container is not None:
+                if can_run_in_robot_version(container.instance, overwritten=True, target_version=target_version):
+                    loaded_transformers.append(container)
     return loaded_transformers
